WgpuKernelOp

Enum WgpuKernelOp 

pub enum WgpuKernelOp {
Show 17 variants Add, Sub, Mul, Div, Neg, Sqrt, Exp, Log, Sin, Cos, Sum, Min, Max, Norm, Transpose, Dot, Matmul,
}
Portable operation implemented by a wgpu tensor kernel.

Variants



Add

Element-wise addition.



Sub

Element-wise subtraction.



Mul

Element-wise multiplication.



Div

Element-wise division.



Neg

Element-wise negation.



Sqrt

Element-wise square root.



Exp

Element-wise exponential.



Log

Element-wise natural logarithm.



Sin

Element-wise sine.



Cos

Element-wise cosine.



Sum

Whole-tensor sum reduction.



Min

Whole-tensor minimum reduction.



Max

Whole-tensor maximum reduction.



Norm

Whole-tensor Euclidean norm.



Transpose

Matrix transpose.



Dot

Vector dot product.



Matmul

Vector or matrix multiplication.

Implementations

Source

impl WgpuKernelOp

pub fn is_binary(self) -> bool

Returns true when the kernel consumes two input tensors.

pub fn is_unary(self) -> bool

Returns true when the kernel consumes exactly one input tensor.

pub fn is_reduction(self) -> bool

Returns true when the kernel performs fixed-tree accumulation.

pub fn is_linalg(self) -> bool

Returns true when the kernel performs a linalg memory/product primitive.