pub struct WgpuResidentStorage { /* private fields */ }Expand description
Resident storage that records a validated wgpu pipeline result.
Implementations
Sourceimpl WgpuResidentStorage
impl WgpuResidentStorage
Sourcepub fn new(
site: Symbol,
allocation: WgpuArenaAllocation,
pipeline: Symbol,
segments: Vec<WgpuResidentSegment>,
shape: Vec<usize>,
dtype: Symbol,
cells: Arc<[Value]>,
) -> Self
pub fn new( site: Symbol, allocation: WgpuArenaAllocation, pipeline: Symbol, segments: Vec<WgpuResidentSegment>, shape: Vec<usize>, dtype: Symbol, cells: Arc<[Value]>, ) -> Self
Builds resident storage around host-equivalent cells.
Sourcepub fn allocation(&self) -> &WgpuArenaAllocation
pub fn allocation(&self) -> &WgpuArenaAllocation
Returns the resident allocation.
Sourcepub fn segments(&self) -> &[WgpuResidentSegment]
pub fn segments(&self) -> &[WgpuResidentSegment]
Returns the segmented resident layout.
Sourcepub fn resident_tensor(&self) -> Option<Tensor>
pub fn resident_tensor(&self) -> Option<Tensor>
Rebuilds a canonical tensor without counting a user materialization.